package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````S!\```````!``````````,BA````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````&^@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````G)0`````
M``"<E``````````0`````````0````8```"8FP```````)BK````````F*L`
M``````"X!````````.`$`````````!`````````"````!@```+";````````
ML*L```````"PJP```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```!@C0```````&"-````````8(T```````#D````````
M`.0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````F)L```````"8
MJP```````)BK````````:`0```````!H!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`"D\)PP>'YY3K:^\^&:GGRK%&)[;!````!`````!````1TY5```````$````
M#P`````````1````1P````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``H@`````1P```$H```!-````3@```%8```!7````60```%L`
M``!<````70```%\```!A````8@```&0``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@
MF4_#FVL)0]9FK\QF&7X*AT)%U>R)!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_
M8?)A?ZF<F^"G`@IK&IY0H^#[20``````````````````````````````````
M`````````P`,`$`>``````````````````#;`@``$0``````````````````
M``````#5````$@````````````````````````#-`0``$@``````````````
M``````````"W`@``$@````````````````````````"'````$@``````````
M``````````````!.`0``$@````````````````````````"*`@``$@``````
M``````````````````#4`0``$@````````````````````````!E`0``$@``
M``````````````````````"5`0``$@````````````````````````#K````
M$@````````````````````````"F`@``$@````````````````````````#!
M`@``$0````````````````````````"1`@``$@``````````````````````
M``"(`0``$@`````````````````````````<`0``$@``````````````````
M```````,`0``$@````````````````````````#^````$@``````````````
M``````````#S`0``$@````````````````````````#;`0``$@``````````
M``````````````#F`0``$@````````````````````````"^`0``$@``````
M``````````````````#)`@``$@`````````````````````````!````(```
M```````````````````````)`@``$@````````````````````````!L`0``
M$@`````````````````````````=````(``````````````````````````W
M`@``$@````````````````````````"F`0``$@``````````````````````
M```W````$@````````````````````````"8`@``$@``````````````````
M``````"_`@``$0````````````````````````!4````%@``````````````
M```````````"`@``$@`````````````````````````^`0``$@``````````
M``````````````"?`@``$@````````````````````````!G````$@``````
M``````````````````!T`@``$@````````````````````````#$````$@``
M``````````````````````!X````$@````````````````````````"-`0``
M$@````````````````````````"H````$@````````````````````````#:
M````$@````````````````````````#%`0``$@``````````````````````
M``!M`@``$@````````````````````````#M`0``$@``````````````````
M```````P`0``$@````````````````````````"?`0``$@``````````````
M``````````!7`@``$@````````````````````````!0`@``$0``````````
M``````````````#?````$@````````````````````````"V`0``$@``````
M```````````````````V`@``$@````````````````````````!>`@``(@``
M``````````````````````"3````$@`````````````````````````2`@``
M$@````````````````````````#A`0``$@````````````````````````![
M`@``$@````````````````````````!9`0``$@``````````````````````
M```H`@``$@````````````````````````"C`P``$@``````````````````
M``````"W````$0`````````````````````````:`@``$@``````````````
M```````````E`0``$@````````````````````````!%````$@``````````
M```````````````^`@``$@````````````````````````""`@``$@``````
M``````````````````!W`0``$@````````````````````````"O`0``$@``
M``````````````````````"L`P``$@`,`.HU````````I``````````^!```
M$@`,`%XO````````W`0```````!+`@``$@`,`$`>````````B@$````````C
M`P``$@`,`&0F`````````@````````!!`P``$@`,`#HT````````L`$`````
M``!D!```$@`,`&8F````````U@$````````D!```$``6`%"P````````````
M```````T`P``$@`,`#PH````````(@````````!7`P``$@`,`+@L````````
M3@````````#$`P``$0`-`.A+````````!``````````!!```$@`,`$Q)````
M````W``````````<!```$@`,`'XE````````*``````````Y!```$``6`'BP
M``````````````````!2!```$@`,`(8N````````V`````````![!```$@`,
M``8M````````1`````````#3`P``$``5``"P``````````````````![`P``
M$@`,`%XH`````````@$```````#O`P``$`#Q_P"X``````````````````!+
M!```$``5`%"P``````````````````!Q!```$0`5`$BP````````"```````
M```,!```$``5`%"P``````````````````#9`P``$@`,`,P?````````(@``
M``````#@`P``$``5``"P```````````````````P!```$@`,`/A(````````
M5`````````#5`P``(``5``"P``````````````````"X`P``$``6`'BP````
M``````````````"1`P``$@`,`&XN````````&`````````!E`P``$@`,`*8E
M````````O@````````"'`P``$@`,`"A*````````L@$```````"#!```$@`,
M`&`I````````6`,`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F
M;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F
M86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P
M96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD
M:7(`<F5A9`!S=')S='(`;6MD:7(`7U]V9G!R:6YT9E]C:&L`9V5T<&ED`')E
M861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS
M=&%T-C0`7U]L:6)C7W-T87)T7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F
M:6YA;&EZ90!S=')C:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A
M8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``
M7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\N-2XS.`!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL
M<#8T9"YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN
M7W5S960`7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O
M:6YT97(D`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B
M<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A
M<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I
M90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N
M,C<````````"``$``P`#``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#
M``,``P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`!``,``0`!``,`
M`0`#``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$``P`!
M``$`!0`#``,``P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0```````0`#`/T"```0````0```
M`+21E@8```4`D`0``!````"SD98&```$`)L$```0````AY&6!@```P"F!```
M``````$``0`'`P``$`````````"'D98&```"`*8$````````F*L````````#
M`````````.X?````````H*L````````#`````````((@````````J*L`````
M```#`````````$@@````````^*\````````#`````````$`>`````````+``
M```````#``````````"P````````&+`````````#`````````$A-````````
M(+`````````#`````````+!/````````*+`````````#`````````+A/````
M````,+`````````#`````````,!/````````.+`````````#`````````,A/
M````````2+`````````#`````````-!/````````H*\````````"`````@``
M````````````J*\````````"````#```````````````L*\````````"````
M#@``````````````N*\````````"````&0``````````````P*\````````"
M````'```````````````R*\````````+````(@``````````````T*\`````
M```"````)```````````````V*\````````"````)@``````````````X*\`
M```````"````,P``````````````Z*\````````"````-P``````````````
M\*\````````"````/P``````````````T*T````````%`````P``````````
M````V*T````````%````!```````````````X*T````````%````!0``````
M````````Z*T````````%````!@``````````````\*T````````%````!P``
M````````````^*T````````%````"````````````````*X````````%````
M"0``````````````"*X````````%````"@``````````````$*X````````%
M````"P``````````````&*X````````%````#0``````````````(*X`````
M```%````#P``````````````**X````````%````$```````````````,*X`
M```````%````$0``````````````.*X````````%````$@``````````````
M0*X````````%````$P``````````````2*X````````%````%```````````
M````4*X````````%````%0``````````````6*X````````%````%@``````
M````````8*X````````%````%P``````````````:*X````````%````&```
M````````````<*X````````%````&@``````````````>*X````````%````
M&P``````````````@*X````````%````'0``````````````B*X````````%
M````'@``````````````D*X````````%````'P``````````````F*X`````
M```%````(```````````````H*X````````%````(P``````````````J*X`
M```````%````)0``````````````L*X````````%````)P``````````````
MN*X````````%````*```````````````P*X````````%````*0``````````
M````R*X````````%````*@``````````````T*X````````%````*P``````
M````````V*X````````%````+```````````````X*X````````%````+0``
M````````````Z*X````````%````+@``````````````\*X````````%````
M+P``````````````^*X````````%````,````````````````*\````````%
M````,0``````````````"*\````````%````,@``````````````$*\`````
M```%````-```````````````&*\````````%````-0``````````````(*\`
M```````%````-@``````````````**\````````%````.```````````````
M,*\````````%````.0``````````````.*\````````%````.@``````````
M````0*\````````%````.P``````````````2*\````````%````/```````
M````````4*\````````%````/0``````````````6*\````````%````/@``
M````````````8*\````````%````0```````````````:*\````````%````
M00``````````````<*\````````%````0@``````````````>*\````````%
M````0P``````````````@*\````````%````1```````````````B*\`````
M```%````10``````````````D*\````````%````1@``````````````````
M``````"7DP``,P/#00.^`S,3`T/]DX(#,Q-3$P"#LH(`9P`.`!>>```#/@XR
M9P,.`!,````7G@```SZ.,6<##@`3````%YX```,^#C%G`PX`$P```!>>```#
M/HXP9P,.`!,````7G@```SX.,&<##@`3````%YX```,^CB]G`PX`$P```!>>
M```#/@XO9P,.`!,````7G@```SZ.+F<##@`3````%YX```,^#BYG`PX`$P``
M`!>>```#/HXM9P,.`!,````7G@```SX.+6<##@`3````%YX```,^CBQG`PX`
M$P```!>>```#/@XL9P,.`!,````7G@```SZ.*V<##@`3````%YX```,^#BMG
M`PX`$P```!>>```#/HXJ9P,.`!,````7G@```SX.*F<##@`3````%YX```,^
MCBEG`PX`$P```!>>```#/@XI9P,.`!,````7G@```SZ.*&<##@`3````%YX`
M``,^#BAG`PX`$P```!>>```#/HXG9P,.`!,````7G@```SX.)V<##@`3````
M%YX```,^CB9G`PX`$P```!>>```#/@XF9P,.`!,````7G@```SZ.)6<##@`3
M````%YX```,^#B5G`PX`$P```!>>```#/HXD9P,.`!,````7G@```SX.)&<#
M#@`3````%YX```,^CB-G`PX`$P```!>>```#/@XC9P,.`!,````7G@```SZ.
M(F<##@`3````%YX```,^#B)G`PX`$P```!>>```#/HXA9P,.`!,````7G@``
M`SX.(6<##@`3````%YX```,^CB!G`PX`$P```!>>```#/@X@9P,.`!,````7
MG@```SZ.'V<##@`3````%YX```,^#A]G`PX`$P```!>>```#/HX>9P,.`!,`
M```7G@```SX.'F<##@`3````%YX```,^CAUG`PX`$P```!>>```#/@X=9P,.
M`!,````7G@```SZ.'&<##@`3````%YX```,^#AQG`PX`$P```!>>```#/HX;
M9P,.`!,````7G@```SX.&V<##@`3````%YX```,^CAIG`PX`$P```!>>```#
M/@X:9P,.`!,````7G@```SZ.&6<##@`3````%YX```,^#AEG`PX`$P```!>>
M```#/HX89P,.`!,````7G@```SX.&&<##@`3````%YX```,^CA=G`PX`$P``
M`!>>```#/@X79P,.`!,````7G@```SZ.%F<##@`3````%YX```,^#A9G`PX`
M$P```!UQANRFY*J'HNC*X$[\EY0``(.T)!4NZ#+D#`@P`&@(/LZ<8#[T@4?O
M\)_X%Y8```,VQA.RA1>5```#-246[R#059>7``"#M^<6@\<'`/'/EY<``(.W
MAQ,7E```$P0$')*7F&-R28-'ITL;!4D`#@63YS<`(PWW2N_PG^["9?)'".28
M80TIJH88X1<W```3!V<-&.47EP```S='%QCI%S<``!,'IPP8[05'8UGW#!N(
M-P!"AJ$%$4>(89,7-P"VEP4GB..A!>,9!_^;!P8`C@<(;+:7`4=*AI<%``"3
MA<5@([`'`._PW[P]Q0ALDPE!`N_P']TJB<Z%%S4``!,%!=KO`$`4*<T(;._P
MG[;O\%_.(G><8+F/`4>]Y^9@1F2F9.)Y2H4&:25A@H#O\'_)%Y0``!,$I`X(
M["'%[_!_T9>7``"#MZ<$A68SAT<`&&,VER,'!YHQMPAL[_"?O7FW"&@!Q>\0
M@&1%M\Z%%S4``!,%9<OO`"`-".A9U>6WD4>!OP5%[_#_N>_PO^4``.\`(`*J
MAQ>5```#-64"@F4P`!-Q`?^!1@%'"HCO\)_A`I"7H0``DX$A@8*````7E0``
M$P5E!9>7``"3A^<$8XBG`)>7``"#MZ?ZD<."AX*`%Y4``!,%10.7E0``DX7%
M`HF-D]<U0/V1OI6%A9G%EY<``(.W9_B1PX*'@H!!$2+@%Y0``!,$1`"#1P0`
M!N2%XY>7``"#M\?XD<<7E0```S6E^8*7[_"_^(5'(P#T`*)@`F1!`8*`:;\Y
M<0;\(OA9Q5K@EY<``(.W)_(#NP<`8P$+"$KP3NQ2Z(-'!0"JB2Z**HD3!]`#
MI<MCAN<`@T<9``4)_?L["3E!`S0+`#G,)O16Y-J$DPK0`TJ&SH4BA>_P?Y^S
M!R0!">6#QP<`8X!7`X!DH01U\*)T`GGB:4)JHFH":^)P(H5"="%A@H"SA&1!
MC80%"2,@F@!*E/&_`435MP)K`43YOP%)1;<">>)I0FH":\&_<7$B\2;M!O67
ME```@[2$YBP`G&`^Y8%'*H3O\'_`#>'B1[UF$6?UCV.%YP`I9V.:YP")12*%
M[_"_GA,U%0`1H`%%*F><8+F/`4>1YZIP"G3J9$UA@H#O\+_),7%.[0;]EYD`
M`(.Y">&#MPD`/N6!1QG%(OF#1P4`*H2)[TIT*F>#MPD`N8\!1V.6!PSJ<.II
M*6&"@";U2O'O\)_$JH11R2:%[_#_E4'!@T8U`1,)-0&;AB;]@>:#1AD`_=(#
M1S4!&P<G_3W+(H52Z>_P?Y$JBDJ%[_#_D#L%J@`))>_P7Y'*AR*'ES8``).&
MQIU]5H5%*HGO\/^Z+`!*A>_P?Y[]5V,(]0#B1[UF$6?UCV.`YP1*A>_P_YA*
MA>_PGZ<FA4IJ[_`?CE'Q)H7O\)^<(H7O\#^52G2J=`IYF;<#1QD`&P<G_5'S
M`T<I`"'?M;]*A>_PW_#1MR+Y)O5*\5+I[_!?N1UQHNBFY,K@4OB&[$[\5O1:
M\(/'!0`7F0```SFISZJ$DX<W_).W%P`SA/4`(H6#-PD`/N2!1^_POX0JBDP`
M)H7O\%_;><FJB>_PGX-C=D4+DDH7FP```SOKS(X*`\<$`*:'DP;0`V,(!Q)C
M!M<``\<7`(4'??N%GX,Y"P`3!2H`/I76F>_PWX`CL*D`,<4#-PL`@\<$`!.%
M%`!6EQ1C$P;0`R.`]@"!Z[V@@T<%``4%HP#W`*W#-H>%!N.8Q_Z3!M`#DP<7
M`",`UP`#1P0`A0<%!*./Y_YU^R)G@S<)`+F/`4?=[^9@1F2F9`9IXGE">J)Z
M`GLE88*`@T<$`(4)!02CC_G^\=N#1P0`A0D%!*./^?[]\]&W-H==MU[L8N@7
MFP```SLKP`,\"P"#-PP`M<?BAX%)F&?.AJ$'A2EE_XTFDY4V`)>7``"3AT?(
MF$,5ZP5'+H68P^_PK_.JBS'%DYHY`%:&XH7O\+^-(S![`9N'&0".![Z;([`+
M`.)K0FQ.PO&]8H7O\-^5(S"K`*J+"<V3FCD`Z;^!1\6UP46!25VW7NQBZ._P
MWY[B:T)L-;==<5;L_7>%:OURX1<3APH!HN`F_$KX3O12\(;D/I<6D:Z)LP4G
M`!.'B@`*EP5D%YD```,Y2;,JBA,&]/\7)0``$P7E=X,W"0`<XX%'[_!O]IL$
M!0!C7I``$X<*`0J7,P2'0)N']/\^E`-'A/\IXYWOEY<``(.WI[%.AM*%DI>(
M8^_P+^V%9Z$'BI>88X,W"0"YCP%'N>>%8A:1IF`&9.)T0GFB>0)ZXFIA88*`
MOH3]=P5GX1=!!SZ7,P0G`":&DP7P`B*%[_#_@475EY<``(.W!ZRFAB*&DI>(
M8]*%[_!O^56W[_`?D$$1(N`7E````S0$J@;DEW8``).&YH"S!T0`B&,7E@``
M`S8&J9<E``"3A05L[_`?B1*4"&`"9*)@%S<``!,'QZ.!1[J&%Q8``!,&)NV7
M)0``DX6%:T$!;_!O\)>7``"#MZ>DEV8``).&IGL7E@```S8FI)*7B&.7)0``
MDX7E9F_P_X-=<2;\^7*)9(;DHN!*^$[T$X>$`1:1"I>7F0``@[DIGH.W"0`<
MXX%'[_`OZ/EWH1>3A@0"OI8SA"8`!68JAY<G``"3A\=EER8``).&QF4%!H5%
M(H7O\&_]_77!%9.'!`*NE[.$)P`BA05FIH7O\._=&P0%``%)8T\$`!L%%`#O
M\,_/*HD!R2*&IH5*E._P[^`C``0`B6?A!XJ7F&.#MPD`N8\!1YGKB6(6D:9@
M2H4&9.)T0GFB>6%A@H#O\`_\B;>%9OUW47']<I.'1_<3AP8)HO&F[<KI8O&&
M]<[ETN%6_5KY7O5F[6KI/I<6D2Z$LP4G`!.'A@@*EQ><```#/"R0*HF#-PP`
M'..!1Q<E```3!05;[_#?G*J$DP7P`DJ%[_#/X2'%%R4``!,%95K*A>_PW[M*
MA85GDX>'"(J7F&.#-PP`N8\!1V.6!Q2%8A:1KG`.=.YD3FFN:0YJZGI*>ZI[
M"GSJ;$IM;6&"@"*%[_#OWY<E``"3A:56[_`ONBJ$7=&%9_UYX1D3AP<)3I>S
M"2<`$X<'"9.'!PF*EX5J?7JSC%=!@T<$`!,*BO=2EY<K``"3BVM3%RL``!,+
M:U,S"B<`R<N1Q**%)H7O\"_/-<4BA>_PK[F3!_7_HI<JC9,&\`)C:/0`,:@C
M@`<`_1=C!O0``\<'`.,)U_XBA>_P#[<JC4J%[_"/MFJ5!07C?57QA45*B-Z'
M(H?:A@5F3H7O\._@TH5.A>_P;\0!Z8.GC/B]9B%G]8]CC^<"ER4``).%)4H!
M1>_PCZTJA.,.!>R#1P0`K?N1Q(/'!`";AR?]F<<%31<D```3!"1%8;^#QQ0`
MZ=?]MX5%3H7O\$^S7?W.A1<E```3!<5$[_!?IDZ%[_#OS56U[_"/WD$1DP7P
M`B+@!N0JA._PC\\9P1,$%0`BA0)DHF!!`6_P;\MY<85G_7)*Z`;T(O`F[!.'
MAP`6D1>)```#.>ER"I>#-PD`'..!1TW!@T<%`*J$R<_O\"^H$P85`(5G*H1C
M[\<*?7=A%\$'NI<SAR<`IH4ZA>_P+[F3!_3_JI>3!O`"8VCU`!&H(X`'`/T7
M8X:G``/'!P#C"=?^?76%9V$5P0>JES.$)P"3!?`"(H7O\(_%#<UC8J0&?76%
M9V$5P0>JES.%)P#O\`_!A6>A!XJ7F&.#-PD`N8\!1Z'GA6(6D:)P`G3B9$)I
M16&"@(5GH0>*EYAC@S<)`+F/`4>=XX5B%I&B<`)TXF1":1<E```3!44Q16%O
M\"^\(P`%`'&_`45MM^_P3\PY<2+X)O1*\$[L!OR7A```@[1$8YQ@/N2!1T``
M%RD``!,)R3&7B0``@[G)8J*%2H7O\$_O%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_`O[67Q%RD``!,)"2^7B0``@[D)7Z*%2H7O\(_K%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_!OZ67Q%RD``!,)R2N7B0``@[E)
M6Z*%2H7O\,_G%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"OY67Q
M%RD``!,)"2F7B0``@[F)5Z*%2H7O\`_D%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_#OX67Q%RD``!,)R267B0``@[G)4Z*%2H7O\$_@%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_`OWF7Q%RD``!,)"2.7B0``@[D)
M4**%2H7O\(_<%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_!OVF7Q
M%RD``!,)R1>7B0``@[E)3**%2H7O\,_8%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_"OUF7Q%RD``!,)B1R7B0``@[F)2**%2H7O\`_5%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_#OTF7Q%RD``!,)R1F7B0``@[G)
M1**%2H7O\$_1%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_`OSV7Q
M%RD``!,)"1>7B0``@[D)0:*%2H7O\(_-%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_!ORV7Q%RD``!,)R0F7B0``@[E)/:*%2H7O\,_)%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"OQV7QHH47)0``$P5E$._PK\:J
MA1G%%R4``!,%90WO\&_FHH47)0``$P4%$._PS\2JA1G%%R4``!,%A1#O\(_D
MHH47)0``$P6E$._P[\*JA07-%R4``!,%)0#O\*_B(F><8+F/`4>IXT)TXG"B
M=`)YXFF7)0``DX4E$!<E```3!24$(6%O\`_@HH47)0``$P4E#>_P;[ZJA7G1
M%R4``!,%)03O\"_>9;_O\,^6`1$BZ`;L%X0```,T)"Y,`!<E```3!04"'&`^
MY(%'[_#ONA7!@T<%``%%B<>3AP?],S7P`")G'&"YCP%'F>?B8$)D!6&"@`%%
M];?O\.^1'7$&["J.%X4```,U12T(81,#@0(N]#+X-OR^Y+K@PNC&[)>'``"#
MMX<GFH9RAH5%F&,ZY`%'&N#OX#_F$P7P#^_@O^%9<:+PP7)!9,[DTN!F[(;T
MINS*Z%;\6OA>]&+P$P>$`!:1"I>7C```@[PL(X.W#``<XX%'"4:!12J*[^#?
M\9,)]?\3U_E#09.SA^D`PA?!DYF/LXGY0&/'"0K!=,$4DP<$`<%KII?]6K.$
M)P"A"QU,%XD``!,)Z21!>P%&SH52A>_@?^UC"%4)7H:FA5*%[^"?^@$E8PI5
M!V-SK`9A%3.$I`!C=I0`H:A]%&-JE`0A1LJ%(H7OX#_G9?G!=T%GP1=!!SZ7
MLP<G`#,%]$!.E<%GH0>*EYAC@[<,`+F/`4>IX\%B%I&F<`9TYF1&::9I!FKB
M>D)[HGL"?.)L96&"@-J9XYUI]WU5X;<7)0``$P5E]._PW^H7)0``$P6E\N_P
M'^KOX'_[01$&Y._@_\@!)>_@G_01P0AAHF!!`8*`.7$F]$KP!OP7B0```SDI
M$:J$3``7)0``$P7E\(,W"0`^Y(%'[_"OG1W%(OB#1P4`*H2-PZ:%[^!?T!W-
M(F>#-PD`N8\!1]'C0G3B<*)T`GDA88*`0G0B9X,W"0"YCP%'IH47)0``$P4%
M[+WCXG"B=`)Y(6%O\&^Y)H5.[._@_\"JB2*%[^!_P$Z5"07OX/_`(HB7)P``
MDX>'UB:'ER8``).&YM9]5H5%*H3OX!_J(F>#-PD`N8\!1Y'KHH7B:4)T%R4`
M`!,%)>95MT[L[^#_["+X3NSOX'_LEX<``).'IPIE<8.X!P$#N(<!D'.4=YA[
MG'_*^L[VTO(&YR+C%XH```,ZZ@$#,PH`&OX!0Q<C```3`^/B$PG!`;[\ER<`
M`).'A^*JB1KP/OP7(P``$P.CRI<G``"3AZ?ARH47)0``$P4%RAKT`OC&Z,+L
MLO"V]+KXON""Y._PKXH1Q8-'!0`JA&.4!QZF_M;N[^`_L0$E[^#?W&,.!10`
M86,+!!0BA>_@W[`&!04%[^!?L0-'!`"JA*J*%</:ZA<K```3"TO<)H7:AGU6
MA47OX%_:`T<4`(D$!01U]U9KA`@7)0``$P6ET"&@B&2A!`W!RH7O\$^#*H1M
MV8-'!0#UU^_P+XU]T2*%[^"_RBJ$&>T$$(!@`<R#1P0`8XP'#"*%[_`OBUWM
M@&2A!'7T(H7OX%^HJH16A>_@WZ>IG)N$1$`FA>_@'ZC6B)<G``"3AR>^%R@`
M`!,(J-,BAY<F``"3AH;3?5:%1:J*[^"_T),%`!Q6A>_@'\+]5V,8]0#OX'^F
M'$%%1V.6YPP,`5:%[^!_QBJ$&>7*1[UF$6?UCV.`YPJ7AP``@[<G[H.V"0"(
M8U:'%R8``!,&)M.%1>_@G\F!1')W@S<*`+F/`4=CG0<NNF`:9/9J5GFV>19Z
M)H7V=%EA@H`BA>_@_[PJA*$$XP,%\C6_`40EOV)U)!@9R<J%[^"?\@'%@T<%
M`(WCB&2A!'WU-47:ZN_@_YJJA*J*%R0``!,$Y,,3!S`%6;WOX)^X*H1IW>_@
M'Y@&!04%E;W:ZFI+[^`_EIL'!0!C!OL$5FN)OQ>'```#-R?C@[8)``AC%R8`
M`!,&1L16AX5%[^"?OH&_[_"?RW)W@S<*`+F/`4=CF`<D(H4:9+I@5GFV>19Z
M66%OX#^RRD?>YN+B$P<`')/W]Q]CAN<`5FNV:Q9LU;TFA>_@/Y'*A:J$%R4`
M`!,%)<COX'_FJH5C#P40`[4)`._PK\.JBV,(!1!>A>_@GXT;"P4`C4=CV&<#
M$P7+_Y<E``"3A67%7I7OX-^@">V11V,'^QB;![O_WI<#QP<`DP?P`F,.]Q;*
MA1<E```3!46G[^"?X&'%@T<%`.G#$P<``V..YPJ7)0``DX4%KQ<E```3!06E
M[^`?_^_@WYHJB)<H``"3B.C.ER<``).'9YU6AY<F``"3AD;!?5:%12:%[^!_
ML'U9Q4D7+```$PQLS)<K``"3B^N:%RL``!,+Z[\EH._@7X4<06.7-P/OX+^5
M!20JB&+@HHC>AU:'VH9]5H5%)H7OX#^LDP4`'":%[^"?G>,()?U6A>_@_YFF
MA1<E```3!863[^`?]B:%[_`?M59KMFL6;/F[@[L)`,6]@45>A>_@7ZXJB1W=
M[_!_GZJ)XTL%\I,%9?\!1DJ%[^"_DQ,+`1`91MJ%2H7OX-^@F4=C'O4(`R<!
M$+='04.3AP<PXQ/W\`-72P"19Y.'AU3C'/?N`4:3A>G\2H7OX-^/(`(3!H`"
MHH5*A>_@_YR3!X`"8Q[U!)<H``"3B*B](HB7)P``DX<'C%:'ER8``).&YJY]
M5H5%)H4C"`$2[^#?GB6_@[F)`.."">A.A>_@S_&-1^/\I^9Q%9<E``"3A86J
M3I7OX'^%XQ(%YLZ+N;T7)0``$P6EJ>_PGX[:ZM[FXN+OX)^?IO[6[MKJWN;B
MXN_@OYXY<2+X%X0```,TI+A*\$[L!OPF]%+HLP=$`(1CDPE!`!>)```#.6FT
M@\<$"\Z%%R4``!,%!88#-PD`.N0!1Z.(]`KOX)_`&<4#1P4`DP<0`V,+]Q+O
M\"_-LP=$`(1C)H6-1@5&ER4``).%I:7OX*_MJH0=P1QI,P=$``ACC&,7)@``
M$P:&I._@#^V<:(QCW$43EY<"8T8'$+,'1`"(8XU&!4:7)0``DX7%HN_@S^FJ
MA!>*```3"NJV#<'.A1<5```3!:5W[^!_N"J&><&<:#,'1``(8XQC[^`/Z+,'
M1`"$8P5&ER4``).%19\FA>_@K]NJA1<F```3!L:?)H7OX*_E$I0<8,Z%%Q4`
M`!,%!7*CB`<*[^"?LR,XJ@`JA#G%DP4`'"*%[^`O^1L'%0"%1V/PYP+%1V,-
M]0"#-XH`JH8BAHQC%R4``!,%Q9WOX,_](F>#-PD`N8\!1['KXG!"=*)T`GGB
M:4)J(6&"@`,UB@#O\'^;(SBJ`"J$7?$7)0``$P7%E^_@3_J#1Q4`XXH'[-FU
M`S>*`)QH#&.(8^_@O^8UO[,'1`"(8^_@#_7]M>_@OX-Y<2+P)NP&]!>$```#
M-.2:JH1,`!<5```3!:5N'&`^Y(%'[^"?IP'-@T<%`(G+$P<``V.&YP"!Q(/'
M!`"9ZR)G'&"YCP%'H>^B<`)TXF1%88*`)H5*Z._P[Z&3!?`"*HGOX&_O&<$3
M"14`2H7OX*_K$4:7%0``DX7%>._@S\89P4)I=;\B9QQ@N8\!1Y'K`G1"::)P
M)H7B9$5A;^!_L$KH[^!O^1,!`=0C.($J(SP1*B,TD2HC,"$K(SPQ*2,X02D7
MA````S1DCS0`P6Y]7QQ@(S3Q*(%'DPB%`Y,"A0<VB!-?#P*W#_\`DXX.\`.V
M"`!!"*$(DU4&`A,7A@&3$X8`DU>&`A->A@"35(8#$Y.%`3-WYP&S\_,!L_?7
M`3-G=P`S?MX!Q8\S<^,!H@4S9\<!&U:&`;/G9P"S]?4!48_-CR,XZ/XC//C^
MXY(2^_U5QG]F?PIGXFX"?B)SPGAB>(9CDX0&((&1$:"R@[!BG&*Z@J$&L8^S
MQ_<!L\?7`1.7%P#]@UV/;8^X_OJ/\HX6CQJ.1H/"B!Z(XYF6_(,^!0"B;P,X
M!0$#,X4`@SB%`0,^!0(WAX):$P>7F9/7O@$3EEX`78ZZGQ-?(P"3%^,!;8[R
MG[-&&`&SY^<!L_9F`'Z6PF\S_[<`L\86`3:6LT;H`6V.L_;6`;J?DQ)6`)-4
MM@'&G[/&!@'^EK/OD@`3V2X`DY/N`?Z6XF^SXR,!L\=W`/&/NI_MCK/'YP'"
MGY.45@`3V;8!DQ+F`?Z7"8*"?[/BP@`SYB0!LI<SQE,`NI^S\[,`=8[MCWZ?
M,T9V`).45P`3V;<!DY_F`7J6B8(B?[/OWP"SYB0!-I:SQO(!;8ZS\K(`_8XZ
MGQZ?DQ16`!-9M@&SQE8`DY/G`8F#L^/S`/J6L^<D`;Z6,_^V`,)VL\=_`/&/
ML_^_`+J6EI:3%%\`$UF_`;/']P&VE[/F)`&VEY,2Y@$)@K/BP@`S]K<`XG>S
MQE,`L_;F`;/SLP"ZE_Z7DQ16`!-9M@&SQG8`OI:SYR0!OI:3'^\!$U\O`+/O
M[P$S_[8`AF:SQ_(!\8^S\K(`NI:>EI,47P`36;\!L\=7`+:7L^8D`;:7DQ/F
M`0F"L^/#`#/VMP"F9[/&?P"S]N8!L_^_`+J7EI>3%%8`$UFV`;/&]@&^EK/G
M)`&^EI,2[P$37R\`L^+B`3/_M@#&9K/'4P#QC[/SLP"ZEOZ6DQ1?`!-9OP&S
MQW<`MI>SYB0!MI>3'^8!"8*S[\\`,_:W`.9GL\;R`;/VY@&S\K(`NI>>EY,4
M5@`36;8!L\96`+Z6L^<D`;Z6DQ/O`1-?+P"SX^,!,_^V`(9VL\=_`/&/L_^_
M`+J6EI:3%%\`$UF_`;/']P&VE[/F)`&VEY,2Y@$)@K/BP@`S]K<`IG>SQE,`
ML_;F`;/SLP"ZE_Z7DQ16`!-9M@&SQG8`OI:SYR0!OI:3'^\!$U\O`+/O[P$S
M_[8`QG:SQ_(!\8^S\K(`NI:>EI,47P`36;\!L\=7`+:7L^8D`;:7DQ/F`0F"
ML^/#`#/VMP#F=[/&?P"S]N8!L_^_`+J7EI>3%%8`$UFV`;/&]@&^EK/G)`&^
MEI,2[P$37R\`L^+B`3/_M@"*9K/'4P#QC[/SLP"ZEOZ6DQ1?`!-9OP&SQW<`
MMI>SYB0!MI>3'^8!"8*S[\\`,_:W`*IGL\;R`;/VY@&S\K(`NI>>EY-4M@&3
M$U8`L\96`!,9[P&^EA-?+P"SYY,`RF,S;^D!OI:SQ^\![8ZS_[\`NI/QCYZ2
MD]2V`;/']P&3DU8`L^.3`):7ZF23$N8!"8*SXL(`GI?MCS-&7P"ZE#-_OP`3
MV;<!=8Z3DU<`II\S1N8!L^,C`;/SLP!^EI.?Y@&)@AZ6L^_?``IYLW2V`+/&
M\@']CK/RL@"3DU0`D]FT`3J9,\=6`+/F,P&3D^<!B8.SX_,`2I^SQW\`[8YZ
ME[&/*G8S#]<`-_?9;A,'%[JS>;\`$]FY`3J6DY99`!:6[8^SYB8!LI?MCKZ6
MDY+D`<IWB8"SXI(`,_FV`#/&4P"S_[\`DU2Y`;J7,T_F`1,660`S?[\`_I=%
MCOJ7;8X^EI.?Z0'J=Y/9*0"S[S\!LW2V`#//\@&S\[,`D]FT`;J7,T_?`).6
M5``S?[\`GI>SYC8!^I?MCKZ6$Q_I`8YG$UDI`#-O+P&S\[8`,\GO`;/YL@"Z
ME[-"R0`3V;,!$Y93`+/RL@#.ES-F)@&6EVV./I:3DN0!KF>)@+/BD@`S25\`
MLW2V`+/YOP"ZE[-/V0`3V;0!DY94`+/_OP#.E[/F)@'^E^V.OI:3G^,!SF>3
MTR,`L^]_`#/)\@&S\[8`LWF_`+J7,T_)`!/9LP$3EE,`,W^_`,Z7,V8F`?J7
M;8X^EA.?Y`'N9XF`,V^?`#/)[P&S=+8`L_FR`+J7LT+9`!/9M`&3EE0`L_*R
M`,Z7L^8F`9:7[8Z^EI.2XP&.=Y/3(P"SXG(`,TE?`+/SM@"S^;\`NI>S3\D`
M$]FS`1.64P"S_[\`SI<S9B8!_I=MCCZ6DY_D`:YWB8"S[Y\`,\GR`;-TM@"S
M>;\`NI<S3]D`$]FT`9.65``S?[\`SI>SYB8!^I?MCKZ6$Y_C`<YWD],C`#-O
M?P`SR>\!L_.V`+/YL@"ZE[-"R0`3V;,!$Y93`+/RL@#.ES-F)@&6EVV./I:3
MDN0![G>)@+/BD@`S25\`LW2V`+/YOP"ZE[-/V0`3V;0!DY94`+/_OP#.E[/F
M)@'^E^V.OI:3G^,!DF>3TR,`L^]_`#/)\@&S\[8`LWF_`+J7,T_)`!/9LP$3
MEE,`,W^_`,Z7,V8F`?J7;8X^EA.?Y`&R9XF`,V^?`#/)[P&S=+8`L_FR`+J7
MLT+9`!/9M`&3EE0`L_*R`,Z7L^8F`9:7[8Z^EI.2XP'29Y/3(P"SXG(`,TE?
M`+/SM@"S^;\`NI>S3\D`$]FS`1.64P"S_[\`SI<S9B8!_I=MCCZ6DY_D`?)G
MB8"S[Y\`,\GR`;-TM@"S>;\`NI<S3]D`$]FT`9.65``S?[\`SI>SYB8!^I?M
MCKZ6$Y_C`9)WD],C`#-O?P`SR>\!L_.V`+/YL@"ZE[-"R0`3V;,!$Y93`+/R
ML@#.ES-F)@&6EVV./I:3DN0!LG>)@+/BD@`S25\`LW2V`+/YOP"ZE[-/V0`3
MV;0!DY94`+/_OP#.E[/F)@'^E^V.OI:3G^,!TG>3TR,`L^]_`#/YM@"SP_(!
MLWF_`+J7,\_#`)-3N0$3%ED`,W^_`,Z7,V9V`&V.^I<SC\<`DY/D`?)WB8"S
MXY,`,\9_`+-TOP"S\K(`NI>QCNV.D]FT`9:7DY)4`+:7L^8R`;:7$Q;I`99F
M$UDI`#-F)@$SR<,`L_*W`+/_OP"S1^D!NI:3V;(!_I83F5(`L_^W`#-I.0'^
MELJ6$Y_D`8F`,V^?`#?WQB.S=+8`_5?UC;9F@9,*!Q,'Q\VS?_\`,V;F`3/Y
M]`&ZEC-V5@"S\_,`MI.3V;4!,V8F`1.950`>EK-C.0$>EK-S]@"3EN(!5F:3
MTB(`L^96`+/R]@`S;]\`,_E?`#J6,W^_`+*4D]FS`3-O+P$3F5,`)I^S9#D!
M$Y;E`2:?B8'V9$V.LW7V`-&.,W__`#/YL@"S]G8`NI3^E)-9OP&SYB8!$QE?
M`*:6LV0Y`1.:XP&3WR,`II:6=+-O^@&S\_\`,V;V`?V.,_EU`+J4,W;F`::2
M,V8F`9.45@`3V;8!L^0D`1:6DQGO`2:6$U\O`+9T,^_I`;-R_P"S[^\!?8XS
M^5,`L__?`+J4L^\O`:Z4$QE6`)-9M@&3E>8!B8+5C;.&GP"S;SD!_I;6?[/T
M]0`S;[\`_8XS^9(`NI\S?\\`,V\O`?Z3$YE6`)/9M@&3'^8!"8*S[\\`,P9_
M`#-O.0%ZEG9_L_/_`+/E]0%]CC/Y=``ZG_6-L^4E`?J2$QE6`)-9M@$3G^8!
MB8(S;]\`LX95`+-E.0&NEIIELW+_`+/O[P']CC/Y4P"ZE;/_SP"S[R\!KI03
MF58`D]FV`9,5Y@$)@M&-,X:?`+-O.0%^EKIOL_3U`#-OOP!]CC/YD@"ZGS-_
MWP`S;R\!_I,3&58`DUFV`9.?Y@&)@K/OWP"S!G\`,V\Y`?J66F^S\_\`L^7U
M`?V.,_ET`#J?\8VSY24!^I(3F58`D]FV`1,?Y@$)@C-OSP`SAE4`LV4Y`2Z6
M^F6S<O\`L^_O`7V.,_E3`+J5L__?`+/O+P&NE!,95@"36;8!DY7F`8F"U8VS
MAI\`LV\Y`?Z6FG^S]/4`,V^_`/V.,_F2`+J?,W_/`#-O+P'^DQ.95@"3V;8!
MDQ_F`0F"L^_/`#,&?P`S;SD!>I8Z?[/S_P"SY?4!?8XS^70`.I_UC;/E)0'Z
MDA,95@"36;8!$Y_F`8F",V_?`+.&50"S93D!KI;:=;-R_P"S[^\!_8XS^5,`
MNI6S_\\`L^\O`:Z4$YE6`)/9M@&3%>8!"8+1C3.&GP"S9#D!)I;Z=+/_]0`S
M;[\`?8XS^?(!,W_?`+J4,V\O`9Z4$QE6`)-9M@&3D^8!B8*SX],`LP:?`+-D
M.0$>:3/_\P"SY74`II;QC;/T[P$ZF?V.%IG%C9.95@`3VK8!DU(F`),4Y@'*
ME3YIL^14`#/F20&S\O0`LI4SYI,`=8ZS\_4`.IFS=5\`?IF3F5,`$]JS`4V.
MD]\F`).5Y@%*EK/F20&SY?4!-I:SYK0`LW3V`%YFL__U`#/Y\@&S]G8`.I9Z
MEK/F)@$3GU0`$]FT`3-O+P&REGYI$Y;C`9/3(P`S9G8`LW/V`/J6T8W]CC/Z
M?P#EC3J9$Y]6`)/9M@$6F;/E10&S8C\!RI43WR0`$YGD`;-DZ0$>?[/R\@"6
ME46.L_+T`#/Y]0`S^E,`=8XZGY-9N0$3%UD`?I\S9D8!LV\W`7J6DYGF`1/?
M)@`S[^D!L\;D`;/__P"MCC>WF#*^=;*?"@<3!V<=L_G_`)/4N0&ZE1.660">
ME?V.18Z3$^D!$UDI`+/C(P%]CJZ6LX7&`#-&?P`S1O8!WG^S]/4`$]FT`;J?
MDY94`):??8ZSYB8!_8Y^EC:6DY_I`?YVD]DI`+/O/P$S>?8`L\+S`;-Y_P"Z
MEC//L@"34KD!DQ59`#-__P#.EK/E50#ZEOV-MI43G^0!@S8!((F`,V^?`+/"
M[P&S]/4`L_/S`)/9M`&ZEK/"P@`3EE0`L_+R`)Z6,V8V`9:6?8XVEI,2Z0&#
M-H$@$UDI`+/B(@&S<_8`,TE?`+/Y_P"ZEK-/N0`3V;,!DY53`+/__P#.EK/E
M)0'^EOV-MI63G^0!@S8!(8F`L^^?`#/)\@&S]/4`LWG_`+J6,T_)`!/9M`$3
MEE0`,W__`,Z6,V8F`?J6?8XVEA.?XP&#-H$AD],C`#-O?P`SR>\!LW/V`+/Y
M\@"ZEK-"N0`3V;,!DY53`+/R\@#.EK/E)0&6EOV-MI63DN0!@S8!(HF`L^*2
M`#-)7P"S]/4`L_G_`+J6LT_)`!/9M`$3EE0`L___`,Z6,V8F`?Z6?8XVEI.?
MXP&#-H$BD],C`+/O?P`SR?(!LW/V`+-Y_P"ZEC-/N0`3V;,!DY53`#-__P#.
MEK/E)0'ZEOV-MI43G^0!@S8!(XF`,V^?`#/)[P&S]/4`L_GR`+J6LT+)`!/9
MM`$3EE0`L_+R`,Z6,V8F`9:6?8XVEI.2XP&#-H$CD],C`+/B<@`S25\`LW/V
M`+/Y_P"ZEK-/N0`3V;,!DY53`+/__P#.EK/E)0'^EOV-MI63G^0!@S8!)(F`
ML^^?`#/)\@&S]/4`LWG_`+J6,T_)`!/9M`$3EE0`,W__`,Z6,V8F`?J6?8XV
MEA.?XP&#-H$DD],C`#-O?P`SR>\!LW/V`+/Y\@"ZEK-"N0`3V;,!DY53`+/R
M\@#.EK/E)0&6EOV-MI63DN0!@S8!)8F`L^*2`#-)7P"S]/4`L_G_`+J6LT_)
M`!/9M`$3EE0`L___`,Z6,V8F`?Z6?8XVEI.?XP&#-H$ED],C`+/O?P`SR?(!
MLW/V`+-Y_P"ZEC-/N0`3V;,!DY53`#-__P#.EK/E)0'ZEOV-MI43G^0!@S8!
M)HF`,V^?`#/Y]0"SQ.\!L_GR`+J6L\+$`)-4N0$3%ED`L_+R`,Z618Z6EGV.
M-I:3E.,!@S:!)I/3(P"SY'0`LT*?`+-S]@"S^?\`NI:SS[(`D]*S`9.54P"S
M__\`SI:SY54`_8W^EK./M@"3$ND!@S8!)Q-9*0"SXB(!L\54`#/Y_P`S?_\`
MDUFY`;J6L8T3%ED`_8WZEC-F-@%]CJZ6LX7&`!.?XP$#-H$GD],C`#-O?P"S
MQN(!L_/U`/V,.I:SQO8!_8XFEI/9LP&3E%,`-I:SYC0!-I:#-@$HDQ_I`1-9
M*0"S[R\!NI:S1/\!,W?V`/:6L_+R`#/&M`!]CI,55P"37K<!EI:REC/FU0&3
ME>,!D],C`+*6L^5U`/V..I,S!L\!,X<%`;.%'P%]CQ3A_8VS=O,`\8\8Z1SQ
M%.4,[0,W@2@<8+F/`4>%XX,P@2L#-`$K@S2!*@,Y`2J#.8$I`SH!*1,!`2R"
M@._0S])!$1,%``@&Y._0#Z*W=EU,-W?I8;<E16>3A14PA@8W5C(0!@<,X9.&
MYL^710``@[5E0Q,&9D<3!P<?#.44Z1#M&/$C-`4"(S@%`B,L!0:B8$$!@H`Y
M<2+X)O1*\%;D!OQ.[%+H&'63%S8`%'FZEX(7@9,SM^<`JH2ZEBA=$U?6`3:7
MG/28^#*)+H23BH0#,>V3!_`#8]PG"1L)"?P;6FD`FPD:`)H)HIFBA1,&``16
MA>_0CZD3!`0$)H7OX-_-XQ4T_QL::@`["4E!2H;.A5:%[]"/IR.L)`?B<$)T
MHG0">>)I0FJB:B%A@H"3"0`$NX>I0+Z)8TKV`AN*"0"3BH0#4H:BA5:5[]`O
MI+Q<$P<`!+N&^0"TW..1YOPFA3L).4%2E._@7\>MM[*)^;>BB7&_>7$B\";L
M4N`&]$KH3N2#N84"$XJ%`Y,&`/@3UCD`$W;V`S,'R@`#N04#DP<6`",`UP`3
M!X`#+H2JA`4F8U?W$A,'``01GY%&,P7Z`&-UUQ2)1V-Y]Q)C%`<2(H7OX+_`
M$P:``X%%4H7OT`^PDU8)`1-7B0"3]O8/H@:;5XD!$W?W#T('U8\3>?D/8@G9
MCQO6B0&3U@D!`A:SYR<!$]>)`)/V]@^B%M&/$W?W#T(7U8_B&=F/L^<W`3SX
M(H7OX+^Z'&`BA>&#(X#T`!Q@P8.C@/0`'&"A@R.!]``<8*.!]``<9.&#(X+T
M`!QDP8.C@O0`'&2A@R.#]``<9*.#]``<:.&#(X3T`!QHP8.CA/0`'&BA@R.%
M]``<:*.%]``<;.&#(X;T`!QLP8.CAO0`'&RA@R.']``<;*.']``<<.&#(XCT
M`!QPP8.CB/0`''"A@R.)]``<<*.)]``"=*)PXF1"::)I`FI%86_0+Y,3!X`#
M.P;'0(%%,P7Z`._0#Y_%O2,`!0#AO2,`!0"C``4`>1<)!>,%!^SMMR,`!0"C
M``4`(P$%`*,!!0!Q%XE'$07C9??JT;^79@``@[9F0F_`__\```$``@``````
M)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P
M<F]C+R5I+R5S```````N`````````%!!4E]414U0``````````!005)?4%)/
M1TY!344`````.@`````````O`````````"5S)7,E<P``4$523#5,24(`````
M`````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)
M04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%
M0E5'`````````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'````
M``````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````#$`````
M````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D``````!,1%],24)205)9
M7U!!5$@`4UE35$5-```O=&UP`````%5315(`````55-%4DY!344`````````
M`"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@
M*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`
M``````!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R96%D````````
M)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE
M=25S```````````8`````````'!E<FP`````,`````````!005(Z.E!A8VME
M<CHZ5D524TE/3@`````Q+C`V,0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@
M9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M
M90```````"TM````````5$U01$E2``!414U01$E2`%1%35``````5$U0````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P``````````0T%#
M2$4``(FKS>\``````1L#.^0````;````X)#__SP&``!LDO___````"23__\0
M`0``T)/__WP!```JE/__J`$``#"5__\``@``WI;__V`"``#$E___H`(``!Z8
M___$`@``1IC__]@"```$F?__$`,```:9__\D`P``W)K__W@#``#^FO__F`,`
M``"<___<`P``6)___Q`$``"FG___-`0``.J?__],!```#J'__YP$```FH?__
MN`0``/ZA__\0!0``VJ;__[P%``"*J/__]`4``"ZI__]P!@``F+O__Z@&``#L
MN___R`8``,B\__\`!P```````!```````````WI2``%\`0$;#0(`$````!@`
M``!HD?__(@`````'`0!H````+`````R2__^L`````$(.0$2!`H@$3)804I((
MDPJ4#&:)!I4.9LE"TD+30M1"U4+60L%$R$(.`$(.0($"B`2)!I((DPJ4#)4.
MEA!0R=+3U-761)800M9$D@B3"I0,EA!&TD+30M1"U@`H````F````$R2__]:
M`````$(.L`%&B`2)!H$"`D8*P4+(0LE"#@!""P```%0```#$````>I+__P8!
M````0@[``423"H$"6(@$1LA0P4+30@X`0@[``8$"B`23"D2)!I((<I0,`E;4
M5`K(0LE"TD(+4I0,2,C)TM1(B`2)!I((E`P```!<````'`$``"B3__^N`0``
M`$(.8%2(!(D&D@B4#($"DPJ5#I80`M`*P4+(0LE"TD+30M1"U4+60@X`0@MN
MEQ*8%`)6"M="V$0+5-?81)<2F!1&U]A$EQ*8%$;70M@````\````?`$``':4
M___F`````$(.4$25#EH.T""(!(D&D@B3"I0,@0(">@H.4$+!0LA"R4+20M-"
MU$+50@X`0@L`(````+P!```<E?__6@````!"#A!"B`1*@0)HR$+!7@X`````
M$````.`!``!2E?__*``````````T````]`$``&:5__^^`````$(.4$2)!E`.
MT$"!`H@$D@B3"@*4"@Y00L%$R$+)0M)"TT(.`$(+`!`````L`@``[)7__P(`
M````````4````$`"``#:E?__U@$```!&#O`!9@[P(8@$B0:2")@4@0*3"I0,
ME0Z6$)<2F1::&`)B"@[P`4+!0LA"R4+20M-"U$+50M9"UT+80ME"VD(.`$(+
M'````)0"``!<E___(@````!"#A!(B`2!`E#(0L%"#@!`````M`(``%Z7__\"
M`0```$(.,%(.L""2"($"B`2)!@*H"@XP0L%"R$+)0M)"#@!""U8*#C!"P4+(
M0LE"TDH.`$0+`#````#X`@``')C__U@#````0@Y`2H@$B0:2"),*@0(#"@,*
MR$+!0LE"TD+34@X`1`L````@````+`,``$";__].`````$(.($2(!($">@K!
M0LA"#@!""P`4````4`,``&J;__]$`````$(.8$*!$@!,````:`,``):;__\D
M`0```$(.<$2(!%P.\(`$DPJ4#)D6@0*)!I((E0Z6$)<2F!0"P@H.<$+!0LA"
MR4+20M-"U$+50M9"UT+80ME"#@!""Q@```"X`P``:IS__Q@`````0@X00H$"
M4,%"#@!4````U`,``&:<___8`````$(.0$:)!I((@0)HB`1:"LA"P4+)0M)"
M#@!""T+(6,%"R4+20@X`1`Y`@0*(!(D&D@A$"I,*`D+30LA*"T*3"D3(TT2(
M!),*J````"P$``#FG/__W`0```!*#I`#6I((DPJ4#($"B`0";(D&E0YNEA!@
MU@/R``K!0LA"U4+20M-"U$3)0@X`0@MR"I805@M4EA!0UF+)U5;(0L%"TD+3
M0M1"#@!$#I`#@0*(!(D&D@B3"I0,E0Z6$$Z7$I@41M9"UT+80I80EQ*8%`,P
M`0K60M="V$(+`^``UM?81I80EQ*8%$3)U=;7V$J)!I4.EA"7$I@4`#0```#8
M!```%J'__[`!````0@Y`0H@$4I((DPJ!`HD&E`P#1@$*P4+(0LE"TD+30M1"
M#@!""P``1````!`%``".HO__I`````!"#C!&B`2)!H$"`D(*P4+(0LE"#@!"
M"T22"&P*TD(+3,A"TD+!1,E"#@!$#C"!`H@$B09"D@@`,````%@%``"<BO__
MB@$```!"#F!,@0*)!H@$D@B3"@,.`0K!0LA"R4+31-)"#@!""P```#0```",
M!0``MJ+__VH2````1`[`!5B(!($"B0:2"),*E`P#,!(*P43(1,E$TD331-1$
M#@!""P``'````,0%``#HM/__5`````!"#A!&@0("2,%"#@`````T````Y`4`
M`!RU___<`````$(.0$Z(!(D&D@B5#H$"DPJ4#`)V"L%"R$+)0M)"TT+40M5"
M#@!""S0````<!@``P+7__[(!````0@XP3(@$B0:4#($"D@B3"@-,`0K(0L%"
MR4+20M-"U$(.`$0+````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````$`````````[0(`````
M```!`````````/T"`````````0`````````'`P```````"``````````F*L`
M```````A``````````@`````````&0````````"@JP```````!L`````````
M"``````````:`````````*BK````````'``````````(`````````/7^_V\`
M````V`(````````%`````````$`-````````!@````````#(`P````````H`
M````````L00````````+`````````!@`````````%0``````````````````
M``,`````````P*T````````"`````````%@%````````%``````````'````
M`````!<`````````,!4````````'`````````"`3````````"`````````!H
M!P````````D`````````&``````````>``````````@`````````^___;P``
M```!```(`````/[__V\`````P!(```````#___]O``````(`````````\/__
M;P````#R$0```````/G__V\`````"P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/__________``````````"0&@```````)`:
M````````D!H```````"0&@```````)`:````````D!H```````"0&@``````
M`)`:````````D!H```````"0&@```````)`:````````D!H```````"0&@``
M`````)`:````````D!H```````"0&@```````)`:````````D!H```````"0
M&@```````)`:````````D!H```````"0&@```````)`:````````D!H`````
M``"0&@```````)`:````````D!H```````"0&@```````)`:````````D!H`
M``````"0&@```````)`:````````D!H```````"0&@```````)`:````````
MD!H```````"0&@```````)`:````````D!H```````"0&@```````)`:````
M````D!H```````"0&@```````)`:````````D!H```````"0&@```````)`:
M````````D!H```````"0&@```````)`:````````D!H```````"0&@``````
M`)`:````````D!H```````"0&@```````)`:````````D!H```````"PJP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H1&5B:6%N(#$S+C(N,"TQ,RD@,3,N,BXP`$%2````<FES8W8``4@`
M```$$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R
M<#!?>FEF96YC96DR<#!?>FUM=6PQ<#```"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE
M:%]F<F%M90`N<')E:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A
M>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+G)I<V-V+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````<`(```````!P`@```````"$````````````````````!````````
M````````````$P````<````"`````````)0"````````E`(````````D````
M````````````````!````````````````````"8````'`````@````````"X
M`@```````+@"````````(`````````````````````0`````````````````
M```T````]O__;P(`````````V`(```````#8`@```````.P`````````!0``
M```````(````````````````````/@````L````"`````````,@#````````
MR`,```````!X"0````````8````"````"``````````8`````````$8````#
M`````@````````!`#0```````$`-````````L00```````````````````$`
M``````````````````!.````____;P(`````````\A$```````#R$0``````
M`,H`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````,`2````````P!(```````!@``````````8````"````"```````````
M`````````&H````$`````@`````````@$P```````"`3````````$`(`````
M```%``````````@`````````&`````````!T````!````$(`````````,!4`
M```````P%0```````%@%````````!0```!0````(`````````!@`````````
M>0````$````&`````````)`:````````D!H```````"P`P``````````````
M````$``````````0`````````'X````!````!@````````!`'@```````$`>
M````````IBT```````````````````0```````````````````"$`````0``
M``(`````````Z$L```````#H2P```````'A!```````````````````(````
M````````````````C`````$````"`````````&"-````````8(T```````#D
M````````````````````!````````````````````)H````!`````@``````
M``!(C@```````$B.````````5`8```````````````````@`````````````
M``````"D````$`````,`````````F*L```````"8FP````````@`````````
M```````````!``````````@`````````LP````X````#`````````*"K````
M````H)L````````(````````````````````"``````````(`````````+\`
M```/`````P````````"HJP```````*B;````````"```````````````````
M``@`````````"`````````#+````!@````,`````````L*L```````"PFP``
M`````!`"````````!@`````````(`````````!``````````U`````$````#
M`````````,"M````````P)T```````!``@``````````````````"```````
M```(`````````-D````!`````P``````````L`````````"@````````4```
M``````````````````@```````````````````#?````"`````,`````````
M4+````````!0H````````"@````````````````````(````````````````
M````Y`````$````P````````````````````4*`````````?````````````
M`````````0`````````!`````````.T````#``!P````````````````````
M`&^@````````4P````````````````````$````````````````````!````
M`P````````````````````````#"H````````/\````````````````````!
/````````````````````
